@@ -15,7 +15,7 @@ if TYPE_CHECKING:
 	from PIL import Image
 
 def phash_antijpeg(image):
-	# type: (Image, ) -> nd.array
+	# type: (Image, ) -> np.ndarray
 
 	""" Source: An Anti-JPEG Compression Image Perceptual Hashing Algorithm
 		`image` is a RGB pillow image.
@@ -76,8 +76,6 @@ def hu_moments(channels):
 		phi6 = (eta20 - eta02)*((eta30 + eta12)**2 - (eta21 + eta03)**2) + 4*eta11*(eta30+eta12)*(eta21 + eta03)
 		phi7 = (3*eta21 - eta03)*(eta30 + eta12)*((eta30 + eta12)**2 - 3*(eta21 + eta03)**2) - (eta30 - 3*eta12)*(eta21 + eta03)*(3*(eta30 + eta12)**2 - (eta21 + eta03)**2)
 
-		# phi5 seems to be wrong...?
-
 		return np.array([phi1, phi2, phi3, phi4, phi5, phi6, phi7])
 
 	return loop()
@@ -99,7 +97,8 @@ def phash_moments(image):
 		`image` is a RGB pillow image. Results should be compared with L^2-Norm of difference vector.
 	"""
 
-	assert image.mode == "RGB"
+	if image.mode != "RGB":
+		raise ValueError("Only RGB images are supported")
 
 	# preprocessing
 	image = image.resize((512, 512), Image.BICUBIC)
