@@ -4,7 +4,9 @@ from typing import TYPE_CHECKING
 from networkx import Graph, connected_components
 
 if TYPE_CHECKING:
+	from typing import Sequence, TypeVar
 	import numpy as np
+	T = TypeVar("T")
 
 def complete_weighted_bipartite_graph(first, second, weights):
 	# type: (Sequence[T], Sequence[T], np.ndarray) -> Graph
@@ -21,5 +23,11 @@ def complete_weighted_bipartite_graph(first, second, weights):
 	return graph
 
 def connected_subgraph(graph, minsize=2):
+	# type: (Graph, int) -> Graph
+
+	""" Returns all the connected subgraphs of `graph`,
+		which are at least of size `minsize`.
+	"""
+
 	nodelist = list(chain.from_iterable(comp for comp in connected_components(graph) if len(comp) >= minsize))
 	return graph.subgraph(nodelist)
